@@ -1,5 +1,3 @@
 #![doc = include_str!("../README.md")]
 
-mod internal;
-pub mod parser;
 pub mod sax;
